@@ -10,11 +10,12 @@
 #' Note, for numeric data the comma is assumed to be US-Style (as '.').
 #' Note, that it is assumed, that any missing fields for the complete tabular view are missing on the right (ie at the end of line) !
 #'
-#' @param fi (character) file-name
+#' @param fiName (character) file-name
 #' @param path (character) optional path
 #' @param sep (character) separator (between columns)
+#' @param header (logical) indicating whether the file contains the names of the variables as its first line.
 #' @param emptyFields (\code{NA} or character) missing headers will be replaced by the content of 'emptyFields', if \code{NA} the last column-name will be re-used and a counter added 
-#' @param refCo  (integer) for custom choice of column to be used as row-names (default will use 1st text-column)
+#' @param refCo (integer) for custom choice of column to be used as row-names (default will use 1st text-column)
 #' @param supNa (character) base for constructing name for columns wo names (+counter starting at 2), default column-name to left of 1st col wo colname
 #' @param silent (logical) suppress messages
 #' @param callFrom (character) allow easier tracking of message(s) produced
@@ -23,19 +24,21 @@
 #' @examples
 #' path1 <- system.file("extdata",package="wrMisc")
 #' fiNa <- "Names1.tsv"
-#' datAll <- readCsvBatch(fiNa,path1)
+#' datAll <- readVarColumns(fiName=file.path(path1,fiNa))
 #' str(datAll)
 #' @export
-readVarColumns <- function(fi,path=NULL,sep="\t",emptyFields=NA,refCo=NULL,supNa=NULL,callFrom=NULL,silent=FALSE) {
+readVarColumns <- function(fiName,path=NULL,sep="\t",header=TRUE,emptyFields=NA,refCo=NULL,supNa=NULL,callFrom=NULL,silent=FALSE) {
   ## slightly slower function for reading variable tabular content of files: This function allows reading variable number of elements per line (via parsing each line separately).
   ##  read content of file using separator 'sep'; 1st line is expectd to caintain some headers, missing headers will be replaced by the content of 'emptyFields'
   ## 'emptyFields'  (NA or character) content of fields
   ## 'refCo'  (integer) for custom choice of column to be used as row-names (default will use 1st text-column)
   ## 'supNa' (character) base for constructing name for columns wo names (+counter starting at 2), default column-name to left of 1st col wo colname
   fxNa <- .composeCallName(callFrom,newNa="readTsv2")
-  fi <- if(length(path)>0) file.path(path,fi) else fi
-  if(!file.exists(fi)) stop(" PROBLEM : Can't find file '",fi,"'")
-  out <- scan(fi, what="character",sep="\n")
+  fiName <- if(length(path)>0) file.path(path,fiName) else fiName
+  if(!file.exists(fiName)) stop(" PROBLEM : Can't find file '",fiName,"'")
+  if(length(header) !=1) header <- FALSE
+  if(!is.logical(header)) stop(" Argument 'header' should be logical and of length=1")
+  out <- scan(fiName, what="character",sep="\n")
   ## parse each line since file does/may contain variable number of columns and/or (many) columns wo colnames
   out <- strsplit(out,sep)
   maxCo <- max(sapply(out,length))
@@ -50,11 +53,13 @@ readVarColumns <- function(fi,path=NULL,sep="\t",emptyFields=NA,refCo=NULL,supNa
   numCol <- apply(out[-1,],2, testNum)
   if(length(refCo) !=1) {refCo <- min(which(!numCol))
     if(!silent) message(fxNa," setting 'refCo' to '",out[1,refCo],"'")}  #
-  dupNa <- duplicated(out[1,])
-  colNa <- if(any(dupNa)) correctToUnique(out[1,]) else out[1,]
-  dupNa <- duplicated(out[-1,refCo])
-  rowNa <- if(any(dupNa)) correctToUnique(out[-1,refCo]) else out[-1,refCo]
-  out <- out[-1,]
+  dupNa <- duplicated(out[1,])  
+  ## integrate colnames and rownames ...
+  useLi <- if(header) 2:nrow(out) else 1:nrow(out)
+  colNa <- if(header) {if(any(dupNa)) correctToUnique(out[1,]) else out[1,]} else NULL
+  dupNa <- duplicated(out[useLi,refCo])
+  rowNa <- if(any(dupNa)) correctToUnique(out[useLi,refCo]) else out[useLi,refCo]
+  if(header) out <- out[-1,]
   dimnames(out) <- list(rowNa,colNa)  
   out }
    
